(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{14:function(e,t,n){e.exports=n(22)},21:function(e,t,n){},22:function(e,t,n){"use strict";n.r(t);var a=n(5),o=n.n(a),r=n(12),s=n.n(r),l=n(0),i=n(1),u=n(2),c=n(3),v=n(8),d=(n(21),function(e){Object(u.a)(n,e);var t=Object(c.a)(n);function n(){var e;Object(i.a)(this,n);for(var a=arguments.length,r=new Array(a),s=0;s<a;s++)r[s]=arguments[s];return(e=t.call.apply(t,[this].concat(r))).render=function(){var t,n,a,r,s=new(0,window.webkitSpeechRecognition);s.interimResults=!0,s.onresult=function(t){var n=Array.from(t.results).map((function(e){return e[0]})).map((function(e){return e.transcript})).join("");e.setState({value:n})},s.onend=function(){e.onSearch(),e.setState({isListening:!1})};var l=e.props.args.subtext,i=e.props.args.suggestions,u=e.props.args.value;return u&&e.setState({value:u}),o.a.createElement("span",null,o.a.createElement("div",{className:"search-form"},o.a.createElement("input",{type:"text",onFocus:e.onFocus,onBlur:e.onBlur,value:null===(t=e.state)||void 0===t?void 0:t.value,placeholder:l,onKeyPress:e._handleKeyDown,onChange:e.onChange,className:"search-input"}),o.a.createElement("button",{type:"button",className:"search-button",onClick:e.onSearch},o.a.createElement("svg",{className:"submit-button"},o.a.createElement("use",{xmlnsXlink:"http://www.w3.org/1999/xlink",xlinkHref:"#search"}))),o.a.createElement("div",{className:"search-option"},o.a.createElement("div",null,o.a.createElement("button",{type:"button",onFocus:e.onFocus,onBlur:e.onBlur,onClick:function(){var t;(null===(t=e.state)||void 0===t?void 0:t.isListening)||s.start(),e.setState({isListening:!0})}},o.a.createElement("svg",{id:"record-button",className:(null===(n=e.state)||void 0===n?void 0:n.isListening)?"recording":""},o.a.createElement("use",{xmlnsXlink:"http://www.w3.org/1999/xlink",xlinkHref:"#user"}))))),o.a.createElement("div",{className:"dropdown",style:{backgroundColor:"white",boxShadow:"0 6px 8px rgba(0, 0, 0, 0.15)"}},o.a.createElement("div",{className:"scroll",style:{maxHeight:(null===(a=e.state)||void 0===a?void 0:a.isActive)?100:"initial",overflowY:(null===(r=e.state)||void 0===r?void 0:r.isActive)?"scroll":"hidden"}},null===i||void 0===i?void 0:i.filter((function(t){var n,a;if(null===(n=e.state)||void 0===n?void 0:n.isActive){if(null!=(null===(a=e.state)||void 0===a?void 0:a.value)&&""!=e.state.value){var o=e.state.value.toLowerCase(),r=t.toLowerCase();return o&&r.startsWith(o)&&r!==o}return t}return""})).map((function(t){return o.a.createElement("div",{className:"dropdown-row",onMouseDown:function(){return e.setSuggestion(t)}},t)})))),o.a.createElement("div",{className:"dropdown"},"\xa0")),o.a.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"0",height:"0",display:"none"},o.a.createElement("symbol",{id:"search",viewBox:"0 0 32 32"},o.a.createElement("path",{d:"M 19.5 3 C 14.26514 3 10 7.2651394 10 12.5 C 10 14.749977 10.810825 16.807458 12.125 18.4375 L 3.28125 27.28125 L 4.71875 28.71875 L 13.5625 19.875 C 15.192542 21.189175 17.250023 22 19.5 22 C 24.73486 22 29 17.73486 29 12.5 C 29 7.2651394 24.73486 3 19.5 3 z M 19.5 5 C 23.65398 5 27 8.3460198 27 12.5 C 27 16.65398 23.65398 20 19.5 20 C 15.34602 20 12 16.65398 12 12.5 C 12 8.3460198 15.34602 5 19.5 5 z"})),o.a.createElement("symbol",{id:"user",viewBox:"0 0 18 18"},o.a.createElement("path",{d:"M3.5 6.5A.5.5 0 0 1 4 7v1a4 4 0 0 0 8 0V7a.5.5 0 0 1 1 0v1a5 5 0 0 1-4.5 4.975V15h3a.5.5 0 0 1 0 1h-7a.5.5 0 0 1 0-1h3v-2.025A5 5 0 0 1 3 8V7a.5.5 0 0 1 .5-.5z"}),o.a.createElement("path",{d:"M10 8a2 2 0 1 1-4 0V3a2 2 0 1 1 4 0v5zM8 0a3 3 0 0 0-3 3v5a3 3 0 0 0 6 0V3a3 3 0 0 0-3-3z"}))))},e.onChange=function(t){e.setState({value:t.target.value})},e.setSuggestion=function(t){e.setState({value:t},(function(){var t;return v.a.setComponentValue(null===(t=e.state)||void 0===t?void 0:t.value)}))},e.onFocus=function(t){e.setState({isActive:!0})},e.onBlur=function(t){e.setState({isActive:!1})},e.onSearch=function(){e.setState((function(){var t;return v.a.setComponentValue(null===(t=e.state)||void 0===t?void 0:t.value)}))},e._handleKeyDown=function(t){"Enter"===t.key&&e.setState((function(){return v.a.setComponentValue(e.state.value)}))},e}return Object(l.a)(n)}(v.b)),m=Object(v.c)(d);s.a.render(o.a.createElement(o.a.StrictMode,null,o.a.createElement(m,null)),document.getElementById("root"))}},[[14,1,2]]]);
//# sourceMappingURL=main.cab3ca62.chunk.js.map